MPubspecNews class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appName ↔ String
-
getter/setter pair
- backFunction ↔ BackFunction
-
getter/setter pair
- catUrl ↔ String
-
getter/setter pair
- getAppflyerFunction ↔ GetAppflyerFunction
-
getter/setter pair
- getCheckChinaAppFunction ↔ CheckChinaApp
-
getter/setter pair
- getCurrencySymbolFunction ↔ CurrencySymbolFunction
-
getter/setter pair
- getGoogleAdsFunction ↔ GoogleAdsFunction
-
getter/setter pair
- getIDFVFunction ↔ GoogleAdsFunction
-
getter/setter pair
- getNetTokenFunction ↔ GetAppflyerFunction
-
getter/setter pair
- getTimeZoneFunction ↔ GoogleAdsFunction
-
getter/setter pair
- isCheckChinaApp ↔ bool
-
getter/setter pair
- launchPageWidget ↔ Widget
-
getter/setter pair
- netUrl ↔ String
-
getter/setter pair
- openUrl ↔ String
-
getter/setter pair
Static Methods
-
initCallBack(
BackFunction backFunction, TimeZoneFunction getTimeZoneFunction, IDFVFunction getIDFVFunction, GoogleAdsFunction getGoogleAdsFunction, GetAppflyerFunction getAppflyerFunction, NetTokenFunction getNetTokenFunction, CurrencySymbolFunction getCurrencySymbolFunction, CheckChinaApp getCheckChinaAppFunction) → void -
initConfig(
String netUrl, String appName, String openUrl, String catUrl, Widget launchPageWidget, {bool isCheckChinaApp = false}) → Future< void>